@@ -151,7 +151,7 @@ void C_DvbInput::OnInit()
   {
     strncpy(filen, dvbrc.GetString(), dvbrc.Length()+1);
   }
-  dvb->init("", "", iNumber, 0);
+  dvb->init("", "", 0, iNumber);
 
   sprintf(devname, DVR_DEV,   iNumber, 0); m_strDVR   = C_String(devname);
   sprintf(devname, DEMUX_DEV, iNumber, 0); m_strDEMUX = C_String(devname);
