@@ -2,7 +2,7 @@
 * tsmux.h: TS multiplexer
 *-------------------------------------------------------------------------------
 * (c)1999-2002 VideoLAN
-* $Id: tsmux.h,v 1.2 2002/04/10 10:17:08 bozo Exp $
+* $Id: tsmux.h,v 1.2.4.1 2003/11/16 17:49:08 nitrox Exp $
 *
 * Authors: Arnaud de Bossoreille de Ribou <bozo@via.ecp.fr>
 *
@@ -56,6 +56,7 @@ public:
   C_TsMuxPmtDecoder(C_NetList *pTsProvider, C_TsMux *pMux, u16 iProgramNumber);
   virtual ~C_TsMuxPmtDecoder();
 
+  uint16_t GetPnr() { return uiPnr;}
   void Detach();
 
 protected:
@@ -64,6 +65,7 @@ protected:
 private:
   // Internal data
   C_TsMux *m_pMux;
+  uint16_t uiPnr;
 };
 
 
